betty.subprocess module - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# betty.subprocess module

Provide a subprocess API.

async betty.subprocess.run_process(runnee: list[str], cwd: pathlib.Path | None = None, shell: bool = False) → asyncio.subprocess.Process

  Run a command in a subprocess.

  Parameters:

    - runnee (`list`[`str`])

    - cwd (`pathlib.Path` | `None`)

    - shell (`bool`)

  Return type:

    `asyncio.subprocess.Process`